@@ -7,6 +7,8 @@
 
 (* C stub generation *)
 
+[@@@warning "-9-27"]
+
 open Ctypes_static
 open Cstubs_c_language
 open Unchecked_function_types
@@ -145,6 +147,7 @@ struct
             `Deref (`Cast (Ty (ptr orig), y)))
     | Abstract _ -> report_unpassable "values of abstract type"
     | View { ty } -> prj ty ~orig x
+    | Qualified (_, ty) -> prj ty ~orig x
     | Array _ -> report_unpassable "arrays"
     | Bigarray _ -> report_unpassable "bigarrays"
     | OCaml String -> Some (string_to_ptr x)
@@ -163,6 +166,7 @@ struct
     | Union u -> `App (copy_bytes, [`Addr (x :> cvar); `Int (Signed.SInt.of_int (sizeof ty))])
     | Abstract _ -> report_unpassable "values of abstract type"
     | View { ty } -> inj ty x
+    | Qualified (_, ty) -> inj ty x
     | Array _ -> report_unpassable "arrays"
     | Bigarray _ -> report_unpassable "bigarrays"
     | OCaml _ -> report_unpassable "ocaml references as return values"
@@ -362,6 +366,7 @@ struct
     | Pointer _ -> Generate_C.of_fatptr x
     | Funptr _ -> Generate_C.of_fatptr x
     | View { ty } -> prj ty ~orig x
+    | Qualified (_, ty) -> prj ty ~orig x
     | t -> unsupported t
 
   let prj ty x = prj ty ~orig:ty x
@@ -483,7 +488,7 @@ struct
   let byte_stub ~errno ~stub_name fmt fn args =
     begin
       let nargs = List.length args in
-      fprintf fmt "@[value@ %s_byte%d@;@[(value *argv, int argc)@]@]@;@[<2>{@\n"
+      fprintf fmt "@[value@ %s_byte%d@;@[(value *argv, int argc)@]@]@;@[<2>{@\n(void)(argc);@\n"
         stub_name nargs;
       fprintf fmt "@[<2>return@ @[%s(@[" stub_name;
       ListLabels.iteri args
