@@ -7,6 +7,8 @@
 
 (* C type construction *)
 
+[@@@warning "-9"]
+
 exception IncompleteType
 exception ModifyingSealedType of string
 exception Unsupported of string
@@ -32,6 +34,8 @@ type _ ocaml_type =
 | Bytes      : bytes ocaml_type
 | FloatArray : float array ocaml_type
 
+type qualifier = Const | Volatile
+
 type _ typ =
     Void            :                       unit typ
   | Primitive       : 'a Ctypes_primitive_types.prim -> 'a typ
@@ -41,6 +45,7 @@ type _ typ =
   | Union           : 'a union_type      -> 'a union typ
   | Abstract        : abstract_type      -> 'a abstract typ
   | View            : ('a, 'b) view      -> 'a typ
+  | Qualified       : qualifier * 'a typ -> 'a typ
   | Array           : 'a typ * int       -> 'a carray typ
   | Bigarray        : (_, 'a, _) Ctypes_bigarray.t
                                          -> 'a typ
@@ -92,28 +97,28 @@ type _ bigarray_class =
     layout: 'l;
     dims: int array;
     ba_repr: 'b;
-    bigarray: ('a, 'b, 'l) Bigarray_compat.Genarray.t;
+    bigarray: ('a, 'b, 'l) Bigarray.Genarray.t;
     carray: 'a carray > bigarray_class
 | Array1 :
   < element: 'a;
     layout: 'l;
     dims: int;
     ba_repr: 'b;
-    bigarray: ('a, 'b, 'l) Bigarray_compat.Array1.t;
+    bigarray: ('a, 'b, 'l) Bigarray.Array1.t;
     carray: 'a carray > bigarray_class
 | Array2 :
   < element: 'a;
     layout: 'l;
     dims: int * int;
     ba_repr: 'b;
-    bigarray: ('a, 'b, 'l) Bigarray_compat.Array2.t;
+    bigarray: ('a, 'b, 'l) Bigarray.Array2.t;
     carray: 'a carray carray > bigarray_class
 | Array3 :
   < element: 'a;
     layout: 'l;
     dims: int * int * int;
     ba_repr: 'b;
-    bigarray: ('a, 'b, 'l) Bigarray_compat.Array3.t;
+    bigarray: ('a, 'b, 'l) Bigarray.Array3.t;
     carray: 'a carray carray carray > bigarray_class
 
 type boxed_typ = BoxedType : 'a typ -> boxed_typ
@@ -134,6 +139,7 @@ let rec sizeof : type a. a typ -> int = function
   | Funptr _                       -> Ctypes_primitives.pointer_size
   | OCaml _                        -> raise IncompleteType
   | View { ty }                    -> sizeof ty
+  | Qualified (_, ty)              -> sizeof ty
 
 let rec alignment : type a. a typ -> int = function
     Void                             -> raise IncompleteType
@@ -150,6 +156,7 @@ let rec alignment : type a. a typ -> int = function
   | Funptr _                         -> Ctypes_primitives.pointer_alignment
   | OCaml _                          -> raise IncompleteType
   | View { ty }                      -> alignment ty
+  | Qualified (_, ty)                -> alignment ty
 
 let rec passable : type a. a typ -> bool = function
     Void                           -> true
@@ -165,22 +172,24 @@ let rec passable : type a. a typ -> bool = function
   | Abstract _                     -> false
   | OCaml _                        -> true
   | View { ty }                    -> passable ty
+  | Qualified (_, ty)              -> passable ty
 
 (* Whether a value resides in OCaml-managed memory.
    Values that reside in OCaml memory cannot be accessed
    when the runtime lock is not held. *)
 let rec ocaml_value : type a. a typ -> bool = function
-    Void        -> false
-  | Primitive _ -> false
-  | Struct _    -> false
-  | Union _     -> false
-  | Array _     -> false
-  | Bigarray _  -> false
-  | Pointer _   -> false
-  | Funptr _    -> false
-  | Abstract _  -> false
-  | OCaml _     -> true
-  | View { ty } -> ocaml_value ty
+    Void              -> false
+  | Primitive _       -> false
+  | Struct _          -> false
+  | Union _           -> false
+  | Array _           -> false
+  | Bigarray _        -> false
+  | Pointer _         -> false
+  | Funptr _          -> false
+  | Abstract _        -> false
+  | OCaml _           -> true
+  | View { ty }       -> ocaml_value ty
+  | Qualified (_, ty) -> ocaml_value ty
 
 let rec has_ocaml_argument : type a. a fn -> bool = function
     Returns _ -> false
@@ -244,7 +253,7 @@ let bigarray_ : type a b c d e l.
     ba_repr: c;
     bigarray: d;
     carray: e > bigarray_class -> 
-   b -> (a, c) Bigarray_compat.kind -> l Bigarray_compat.layout -> d typ =
+   b -> (a, c) Bigarray.kind -> l Bigarray.layout -> d typ =
   fun spec dims kind l -> match spec with
   | Genarray -> Bigarray (Ctypes_bigarray.bigarray dims kind l)
   | Array1 -> Bigarray (Ctypes_bigarray.bigarray1 dims kind l)
@@ -253,8 +262,8 @@ let bigarray_ : type a b c d e l.
   | Array3 -> let d1, d2, d3 = dims in
               Bigarray (Ctypes_bigarray.bigarray3 d1 d2 d3 kind l)
 
-let bigarray spec c k = bigarray_ spec c k Bigarray_compat.c_layout
-let fortran_bigarray spec c k = bigarray_ spec c k Bigarray_compat.fortran_layout
+let bigarray spec c k = bigarray_ spec c k Bigarray.c_layout
+let fortran_bigarray spec c k = bigarray_ spec c k Bigarray.fortran_layout
 
 let returning v =
   if not (passable v) then
@@ -272,6 +281,16 @@ let offsetof { foffset } = foffset
 let field_type { ftype } = ftype
 let field_name { fname } = fname
 
+let rec const : type a. a typ -> a typ = function
+  | Qualified (Const, _) as ty -> ty
+  | Qualified (Volatile, ty) -> Qualified (Volatile, const ty)
+  | ty -> Qualified (Const, ty)
+
+let rec volatile : type a. a typ -> a typ = function
+  | Qualified (Volatile, _) as ty -> ty
+  | Qualified (Const, ty) -> Qualified (Const, volatile ty)
+  | ty -> Qualified (Volatile, ty)
+
 (* This corresponds to the enum in ctypes_primitives.h *)
 type arithmetic =
     Int8
