@@ -26,6 +26,8 @@ type 'a structspec =
     Incomplete of incomplete_size
   | Complete of structured_spec
 
+type qualifier = Const | Volatile
+
 type _ typ =
     Void            :                       unit typ
   | Primitive       : 'a Ctypes_primitive_types.prim -> 'a typ
@@ -35,6 +37,7 @@ type _ typ =
   | Union           : 'a union_type      -> 'a union typ
   | Abstract        : abstract_type      -> 'a abstract typ
   | View            : ('a, 'b) view      -> 'a typ
+  | Qualified       : qualifier * 'a typ -> 'a typ
   | Array           : 'a typ * int       -> 'a carray typ
   | Bigarray        : (_, 'a, _) Ctypes_bigarray.t
                                          -> 'a typ
@@ -84,28 +87,28 @@ type _ bigarray_class =
     layout: 'l;
     dims: int array;
     ba_repr: 'b;
-    bigarray: ('a, 'b, 'l) Bigarray_compat.Genarray.t;
+    bigarray: ('a, 'b, 'l) Bigarray.Genarray.t;
     carray: 'a carray > bigarray_class
 | Array1 :
   < element: 'a;
     layout: 'l;
     dims: int;
     ba_repr: 'b;
-    bigarray: ('a, 'b, 'l) Bigarray_compat.Array1.t;
+    bigarray: ('a, 'b, 'l) Bigarray.Array1.t;
     carray: 'a carray > bigarray_class
 | Array2 :
   < element: 'a;
     layout: 'l;
     dims: int * int;
     ba_repr: 'b;
-    bigarray: ('a, 'b, 'l) Bigarray_compat.Array2.t;
+    bigarray: ('a, 'b, 'l) Bigarray.Array2.t;
     carray: 'a carray carray > bigarray_class
 | Array3 :
   < element: 'a;
     layout: 'l;
     dims: int * int * int;
     ba_repr: 'b;
-    bigarray: ('a, 'b, 'l) Bigarray_compat.Array3.t;
+    bigarray: ('a, 'b, 'l) Bigarray.Array3.t;
     carray: 'a carray carray carray > bigarray_class
 
 type boxed_typ = BoxedType : 'a typ -> boxed_typ
@@ -163,16 +166,16 @@ val bigarray : < ba_repr : 'c;
                  bigarray : 'd;
                  carray : 'e;
                  dims : 'b;
-                 layout: Bigarray_compat.c_layout;
+                 layout: Bigarray.c_layout;
                  element : 'a > bigarray_class ->
-  'b -> ('a, 'c) Bigarray_compat.kind -> 'd typ
+  'b -> ('a, 'c) Bigarray.kind -> 'd typ
 val fortran_bigarray : < ba_repr : 'c;
                          bigarray : 'd;
                          carray : 'e;
                          dims : 'b;
-                         layout: Bigarray_compat.fortran_layout;
+                         layout: Bigarray.fortran_layout;
                          element : 'a > bigarray_class ->
-  'b -> ('a, 'c) Bigarray_compat.kind -> 'd typ
+  'b -> ('a, 'c) Bigarray.kind -> 'd typ
 val returning : 'a typ -> 'a fn
 val static_funptr : 'a fn -> 'a static_funptr typ
 val structure : string -> 'a structure typ
@@ -180,6 +183,8 @@ val union : string -> 'a union typ
 val offsetof : ('a, 'b) field -> int
 val field_type : ('a, 'b) field -> 'a typ
 val field_name : ('a, 'b) field -> string
+val const : 'a typ -> 'a typ
+val volatile : 'a typ -> 'a typ
 
 exception IncompleteType
 exception ModifyingSealedType of string
