@@ -6,14 +6,13 @@
  *)
 
 open OUnit2
-open Ctypes
 
+let _ = Dl.(dlopen ~filename:"../clib/clib.so" ~flags:[RTLD_NOW])
 
 module Common_tests(S : Cstubs.FOREIGN with type 'a result = 'a
                                         and type 'a return = 'a) =
 struct
   module M = Functions.Common(S)
-  open M
 
   (*
     Test passing bool values.
