@@ -8,7 +8,8 @@
 open OUnit2
 open Ctypes
 open Unsigned
-open Foreign
+
+let _ = Dl.(dlopen ~filename:"../clib/clib.so" ~flags:[RTLD_NOW])
 
 module Common_tests(S : Cstubs.FOREIGN with type 'a result = 'a
                                         and type 'a return = 'a) =
